@@ -23,7 +23,7 @@
 
 #include <gst/gst.h>
 
-typedef enum 
+typedef enum
 {
   GST_EDITOR_IMAGE_BIN,
   GST_EDITOR_IMAGE_PIPELINE,
@@ -39,14 +39,15 @@ typedef enum
 
 typedef struct _GstEditorImage GstEditorImage;
 
-struct _GstEditorImage {
+struct _GstEditorImage
+{
   GdkPixmap *pixmap;
   GdkBitmap *bitmap;
 };
 
 
-GstEditorImage *gst_editor_image_get(GstEditorImageType type);
-GstEditorImage *gst_editor_image_get_for_type(GtkType type);
+GstEditorImage *gst_editor_image_get (GstEditorImageType type);
+GstEditorImage *gst_editor_image_get_for_type (GtkType type);
 
 
 #endif /* __GST_EDITOR_IMAGE_H__ */
