@@ -24,12 +24,9 @@
 #include        <gdk-pixbuf/gdk-pixbuf.h>
 
 G_BEGIN_DECLS
-
-GString*	pixdata_to_csource	(GdkPixdata		*pixdata,
-					 const gchar		*name,
-					 GdkPixdataDumpType	 dump_type);
+    GString * pixdata_to_csource (GdkPixdata * pixdata,
+    const gchar * name, GdkPixdataDumpType dump_type);
 
 
 G_END_DECLS
-
 #endif /* __PIXDATA_H__ */
